@@ -8,15 +8,21 @@
 #' Character string "all" is shorthand for that vector, character string "most" for the same vector without "Enhances", character string "strong" (default) for the first three elements of that vector.
 #' Default: `c("Depends", "Imports", "LinkingTo")`
 #' @param lifeduration logical if to assess life duration for each package in the library. `MEATCRAN CRANDB` is used for libraries with less than 500 packages. The direct web page download from CRAN or local evaluation for newest packages otherwise. Default: FALSE
+#' @param built logical if to add an R version under which each package was installed.
+#' Useful mainly for a local usage.
+#' Packages installed with a previous version of R could not work correctly with the new version of R. Default: `FALSE`
 #' @param checkred list with two named fields, `scope` and `flavor`. `scope` of R CRAN check pages statuses to consider, any of `c("ERROR", "FAIL", "WARN", "NOTE")`. `flavor` is a vector of CRAN machines to consider, which might be retrieved with `pacs::cran_flavors()$Flavor`. By default an empty scope field deactivated assessment for `checkred` column, and NULL flavor will results in checking all machines. Default `list(scope = character(0), flavor = NULL)`
 #' @param repos character vector base URLs of the repositories to use. By default checking CRAN and newest Bioconductor per R version. Default `pacs::biocran_repos()`
-#' @return data.frame with 4/6/7/8 columns.
+#' @return data.frame with 4/6/8/9/10 columns.
 #' \describe{
 #' \item{Package}{character a package name.}
 #' \item{Version.expected.min}{character expected by DESCRIPTION files minimal version. "" means not specified so the newest version.}
 #' \item{Version.have}{character installed package version.}
 #' \item{version_status}{ numeric -1/0/1 which comes from `utils::compareVersion` function.
 #' 0 means that we have the same version as required by DESCRIPTION files. -1 means we have too low version installed, this is an error. 1 means we have higher version.}
+#' \item{built}{character package was built under this R version}
+#' \item{built_status}{integer if the package was built under the current R version, then 1 (good) and for older R versions 0 (possibly bad).
+#' A package built under older R version or mix of packages built under different versions could bring possible failures.}
 #' \item{newest}{logical (Internet needed) if the installed version is the newest one. For Bioconductor if is the newest one per R version.}
 #' \item{cran}{logical (Internet needed) if the package is on CRAN, version is not taken into account here.}
 #' \item{checkred}{(Optional) (Internet needed) logical if the NEWEST package contains any specified statuses on CRAN check page. `pacs::checked_packages` is used to quickly retrieve all statuses at once.}
@@ -49,6 +55,7 @@ lib_validate <- function(lib.loc = .libPaths(),
                          fields = c("Depends", "Imports", "LinkingTo"),
                          lifeduration = FALSE,
                          checkred = list(scope = character(0), flavors = NULL),
+                         built = FALSE,
                          repos = biocran_repos()) {
   fields <- expand_dependency(fields)
   stopifnot(is.null(lib.loc) || (all(lib.loc %in% .libPaths()) && (length(list.files(lib.loc)) > 0)))
@@ -59,17 +66,22 @@ lib_validate <- function(lib.loc = .libPaths(),
     (is.null(checkred$flavors) || all(checkred$flavors %in% cran_flavors()$Flavor)))
   stopifnot(is.character(repos))
   stopifnot(is.logical(lifeduration))
+  stopifnot(is.logical(built))
 
-  installed_agg <- installed_agg_fun(lib.loc, fields)
+  installed_agg <- installed_agg_fun(lib.loc, "Built")
   res_agg <- installed_descriptions(lib.loc, fields)
 
+  Rv <- paste0(R.Version()[c("major", "minor")], collapse = ".")
+
   result <- merge(
     res_agg,
     rbind(
-      installed_agg[, c("Package", "Version")],
+      installed_agg[, c("Package", "Version", "Built")],
       data.frame(
         Package = "R",
-        Version = paste0(R.Version()[c("major", "minor")], collapse = "."), stringsAsFactors = FALSE
+        Version = Rv,
+        Built = Rv,
+        stringsAsFactors = FALSE
       )
     ),
     by = "Package",
@@ -79,6 +91,12 @@ lib_validate <- function(lib.loc = .libPaths(),
 
   result$version_status <- apply(result, 1, function(x) utils::compareVersion(x["Version.have"], x["Version.expected.min"]))
 
+  if (built) {
+    result$built <- result$Built
+    result$built_status <- as.integer(result$Built == Rv)
+  }
+  result$Built <- NULL
+
   result <- result[!is.na(result$Package) & !(result$Package %in% c("", "NA", pacs_base())), ]
 
   if (is_online()) {
@@ -153,6 +171,7 @@ pac_validate <- function(pac,
   descriptions_pac_direct <- pac_deps(pac, lib.loc = lib.loc, fields = fields, description_v = TRUE, recursive = FALSE)
 
   installed_pac <- pac_deps(pac, lib.loc = lib.loc, fields = fields)
+  installed_agg <- installed_agg_fun(lib.loc, "Built")
 
   result <- merge(
     descriptions_pac,
@@ -164,6 +183,18 @@ pac_validate <- function(pac,
 
   if (nrow(result)) {
     result$version_status <- apply(result, 1, function(x) utils::compareVersion(x["Version.have"], x["Version.expected.min"]))
+
+    result <- merge(
+      result,
+      installed_agg[, c("Package", "Built")],
+      by = "Package"
+    )
+
+    Rv <- paste0(R.Version()[c("major", "minor")], collapse = ".")
+    result$built <- result$Built
+    result$built_status <- as.integer(result$Built == Rv)
+    result$Built <- NULL
+
     result <- result[!is.na(result$Package) & !(result$Package %in% c("", "NA", pacs_base())), ]
     result$direct <- result$Package %in% descriptions_pac_direct$Package
 
@@ -268,6 +299,7 @@ lock_validate <- function(path,
       result <- result_renv
       colnames(result) <- c("Package", "Version.expected")
     }
+
     result <- result[!is.na(result$Package) & !(result$Package %in% c("", "NA", pacs_base())), ]
     result <- validate_online(result, "Version.expected", lifeduration, checkred, repos)
   } else {
